@@ -4,8 +4,8 @@ use 5.010;
 
 use Devel::Optrace -all;
 
-foreach my $i(1, 2){
-	print $i, "\n";
+foreach my $i(reverse 1, 2){
+	say $i;
 }
 
 foreach (10){
